module NonDigitEscapes (nonDigitEscapes) where

{-| The nonDigitEscapes dictionary used in Unicode.elm is defined here.
-}

import Dict exposing (Dict, fromList)


{-| arg1 => arg2 == (=>) arg1 arg2 == ( arg1, arg2 )
    More about (,) at http://elm-lang.org/docs/syntax.
-}
(=>) : a -> b -> ( a, b )
(=>) =
  (,)


nonDigitEscapes : Dict String String
nonDigitEscapes =
  fromList
    [ "&Tab;" => " "
    , "&NewLine;" => " "
    , "&excl;" => "!"
    , "&QUOT;" => "\""
    , "&quot;" => "\""
    , "&num;" => "#"
    , "&dollar;" => "$"
    , "&percnt;" => "%"
    , "&AMP;" => "&"
    , "&amp;" => "&"
    , "&apos;" => "'"
    , "&lpar;" => "("
    , "&rpar;" => ")"
    , "&midast;" => "*"
    , "&ast;" => "*"
    , "&plus;" => "+"
    , "&comma;" => ","
    , "&period;" => "."
    , "&sol;" => "/"
    , "&colon;" => ":"
    , "&semi;" => ";"
    , "&LT;" => "<"
    , "&lt;" => "<"
    , "&equals;" => "="
    , "&GT;" => ">"
    , "&gt;" => ">"
    , "&quest;" => "?"
    , "&commat;" => "@"
    , "&lbrack;" => "["
    , "&lsqb;" => "["
    , "&bsol;" => "\\"
    , "&rbrack;" => "]"
    , "&rsqb;" => "]"
    , "&Hat;" => "^"
    , "&lowbar;" => "_"
    , "&DiacriticalGrave;" => "`"
    , "&grave;" => "`"
    , "&lbrace;" => "{"
    , "&lcub;" => "{"
    , "&VerticalLine;" => "|"
    , "&vert;" => "|"
    , "&verbar;" => "|"
    , "&rbrace;" => "}"
    , "&rcub;" => "}"
    , "&NonBreakingSpace;" => " "
    , "&nbsp;" => " "
    , "&iexcl;" => "¡"
    , "&cent;" => "¢"
    , "&pound;" => "£"
    , "&curren;" => "¤"
    , "&yen;" => "¥"
    , "&brvbar;" => "¦"
    , "&sect;" => "§"
    , "&uml;" => "¨"
    , "&DoubleDot;" => "¨"
    , "&die;" => "¨"
    , "&Dot;" => "¨"
    , "&COPY;" => "©"
    , "&copy;" => "©"
    , "&ordf;" => "ª"
    , "&laquo;" => "«"
    , "&not;" => "¬"
    , "&shy;" => "\xAD"
    , "&REG;" => "®"
    , "&circledR;" => "®"
    , "&reg;" => "®"
    , "&strns;" => "¯"
    , "&OverBar;" => "¯"
    , "&macr;" => "¯"
    , "&deg;" => "°"
    , "&PlusMinus;" => "±"
    , "&pm;" => "±"
    , "&plusmn;" => "±"
    , "&sup2;" => "²"
    , "&sup3;" => "³"
    , "&DiacriticalAcute;" => "´"
    , "&acute;" => "´"
    , "&micro;" => "µ"
    , "&para;" => "¶"
    , "&CenterDot;" => "·"
    , "&centerdot;" => "·"
    , "&middot;" => "·"
    , "&Cedilla;" => "¸"
    , "&cedil;" => "¸"
    , "&sup1;" => "¹"
    , "&ordm;" => "º"
    , "&raquo;" => "»"
    , "&frac14;" => "¼"
    , "&half;" => "½"
    , "&frac12;" => "½"
    , "&frac34;" => "¾"
    , "&iquest;" => "¿"
    , "&Agrave;" => "À"
    , "&Aacute;" => "Á"
    , "&Acirc;" => "Â"
    , "&Atilde;" => "Ã"
    , "&Auml;" => "Ä"
    , "&Aring;" => "Å"
    , "&AElig;" => "Æ"
    , "&Ccedil;" => "Ç"
    , "&Egrave;" => "È"
    , "&Eacute;" => "É"
    , "&Ecirc;" => "Ê"
    , "&Euml;" => "Ë"
    , "&Igrave;" => "Ì"
    , "&Iacute;" => "Í"
    , "&Icirc;" => "Î"
    , "&Iuml;" => "Ï"
    , "&ETH;" => "Ð"
    , "&Ntilde;" => "Ñ"
    , "&Ograve;" => "Ò"
    , "&Oacute;" => "Ó"
    , "&Ocirc;" => "Ô"
    , "&Otilde;" => "Õ"
    , "&Ouml;" => "Ö"
    , "&times;" => "×"
    , "&Oslash;" => "Ø"
    , "&Ugrave;" => "Ù"
    , "&Uacute;" => "Ú"
    , "&Ucirc;" => "Û"
    , "&Uuml;" => "Ü"
    , "&Yacute;" => "Ý"
    , "&THORN;" => "Þ"
    , "&szlig;" => "ß"
    , "&agrave;" => "à"
    , "&aacute;" => "á"
    , "&acirc;" => "â"
    , "&atilde;" => "ã"
    , "&auml;" => "ä"
    , "&aring;" => "å"
    , "&aelig;" => "æ"
    , "&ccedil;" => "ç"
    , "&egrave;" => "è"
    , "&eacute;" => "é"
    , "&ecirc;" => "ê"
    , "&euml;" => "ë"
    , "&igrave;" => "ì"
    , "&iacute;" => "í"
    , "&icirc;" => "î"
    , "&iuml;" => "ï"
    , "&eth;" => "ð"
    , "&ntilde;" => "ñ"
    , "&ograve;" => "ò"
    , "&oacute;" => "ó"
    , "&ocirc;" => "ô"
    , "&otilde;" => "õ"
    , "&ouml;" => "ö"
    , "&div;" => "÷"
    , "&divide;" => "÷"
    , "&oslash;" => "ø"
    , "&ugrave;" => "ù"
    , "&uacute;" => "ú"
    , "&ucirc;" => "û"
    , "&uuml;" => "ü"
    , "&yacute;" => "ý"
    , "&thorn;" => "þ"
    , "&yuml;" => "ÿ"
    , "&Amacr;" => "Ā"
    , "&amacr;" => "ā"
    , "&Abreve;" => "Ă"
    , "&abreve;" => "ă"
    , "&Aogon;" => "Ą"
    , "&aogon;" => "ą"
    , "&Cacute;" => "Ć"
    , "&cacute;" => "ć"
    , "&Ccirc;" => "Ĉ"
    , "&ccirc;" => "ĉ"
    , "&Cdot;" => "Ċ"
    , "&cdot;" => "ċ"
    , "&Ccaron;" => "Č"
    , "&ccaron;" => "č"
    , "&Dcaron;" => "Ď"
    , "&dcaron;" => "ď"
    , "&Dstrok;" => "Đ"
    , "&dstrok;" => "đ"
    , "&Emacr;" => "Ē"
    , "&emacr;" => "ē"
    , "&Edot;" => "Ė"
    , "&edot;" => "ė"
    , "&Eogon;" => "Ę"
    , "&eogon;" => "ę"
    , "&Ecaron;" => "Ě"
    , "&ecaron;" => "ě"
    , "&Gcirc;" => "Ĝ"
    , "&gcirc;" => "ĝ"
    , "&Gbreve;" => "Ğ"
    , "&gbreve;" => "ğ"
    , "&Gdot;" => "Ġ"
    , "&gdot;" => "ġ"
    , "&Gcedil;" => "Ģ"
    , "&Hcirc;" => "Ĥ"
    , "&hcirc;" => "ĥ"
    , "&Hstrok;" => "Ħ"
    , "&hstrok;" => "ħ"
    , "&Itilde;" => "Ĩ"
    , "&itilde;" => "ĩ"
    , "&Imacr;" => "Ī"
    , "&imacr;" => "ī"
    , "&Iogon;" => "Į"
    , "&iogon;" => "į"
    , "&Idot;" => "İ"
    , "&inodot;" => "ı"
    , "&imath;" => "ı"
    , "&IJlig;" => "Ĳ"
    , "&ijlig;" => "ĳ"
    , "&Jcirc;" => "Ĵ"
    , "&jcirc;" => "ĵ"
    , "&Kcedil;" => "Ķ"
    , "&kcedil;" => "ķ"
    , "&kgreen;" => "ĸ"
    , "&Lacute;" => "Ĺ"
    , "&lacute;" => "ĺ"
    , "&Lcedil;" => "Ļ"
    , "&lcedil;" => "ļ"
    , "&Lcaron;" => "Ľ"
    , "&lcaron;" => "ľ"
    , "&Lmidot;" => "Ŀ"
    , "&lmidot;" => "ŀ"
    , "&Lstrok;" => "Ł"
    , "&lstrok;" => "ł"
    , "&Nacute;" => "Ń"
    , "&nacute;" => "ń"
    , "&Ncedil;" => "Ņ"
    , "&ncedil;" => "ņ"
    , "&Ncaron;" => "Ň"
    , "&ncaron;" => "ň"
    , "&napos;" => "ŉ"
    , "&ENG;" => "Ŋ"
    , "&eng;" => "ŋ"
    , "&Omacr;" => "Ō"
    , "&omacr;" => "ō"
    , "&Odblac;" => "Ő"
    , "&odblac;" => "ő"
    , "&OElig;" => "Œ"
    , "&oelig;" => "œ"
    , "&Racute;" => "Ŕ"
    , "&racute;" => "ŕ"
    , "&Rcedil;" => "Ŗ"
    , "&rcedil;" => "ŗ"
    , "&Rcaron;" => "Ř"
    , "&rcaron;" => "ř"
    , "&Sacute;" => "Ś"
    , "&sacute;" => "ś"
    , "&Scirc;" => "Ŝ"
    , "&scirc;" => "ŝ"
    , "&Scedil;" => "Ş"
    , "&scedil;" => "ş"
    , "&Scaron;" => "Š"
    , "&scaron;" => "š"
    , "&Tcedil;" => "Ţ"
    , "&tcedil;" => "ţ"
    , "&Tcaron;" => "Ť"
    , "&tcaron;" => "ť"
    , "&Tstrok;" => "Ŧ"
    , "&tstrok;" => "ŧ"
    , "&Utilde;" => "Ũ"
    , "&utilde;" => "ũ"
    , "&Umacr;" => "Ū"
    , "&umacr;" => "ū"
    , "&Ubreve;" => "Ŭ"
    , "&ubreve;" => "ŭ"
    , "&Uring;" => "Ů"
    , "&uring;" => "ů"
    , "&Udblac;" => "Ű"
    , "&udblac;" => "ű"
    , "&Uogon;" => "Ų"
    , "&uogon;" => "ų"
    , "&Wcirc;" => "Ŵ"
    , "&wcirc;" => "ŵ"
    , "&Ycirc;" => "Ŷ"
    , "&ycirc;" => "ŷ"
    , "&Yuml;" => "Ÿ"
    , "&Zacute;" => "Ź"
    , "&zacute;" => "ź"
    , "&Zdot;" => "Ż"
    , "&zdot;" => "ż"
    , "&Zcaron;" => "Ž"
    , "&zcaron;" => "ž"
    , "&fnof;" => "ƒ"
    , "&imped;" => "Ƶ"
    , "&gacute;" => "ǵ"
    , "&jmath;" => "ȷ"
    , "&circ;" => "ˆ"
    , "&Hacek;" => "ˇ"
    , "&caron;" => "ˇ"
    , "&Breve;" => "˘"
    , "&breve;" => "˘"
    , "&DiacriticalDot;" => "˙"
    , "&dot;" => "˙"
    , "&ring;" => "˚"
    , "&ogon;" => "˛"
    , "&DiacriticalTilde;" => "˜"
    , "&tilde;" => "˜"
    , "&DiacriticalDoubleAcute;" => "˝"
    , "&dblac;" => "˝"
    , "&DownBreve;" => "̑"
    , "&UnderBar;" => "̲"
    , "&Alpha;" => "Α"
    , "&Beta;" => "Β"
    , "&Gamma;" => "Γ"
    , "&Delta;" => "Δ"
    , "&Epsilon;" => "Ε"
    , "&Zeta;" => "Ζ"
    , "&Eta;" => "Η"
    , "&Theta;" => "Θ"
    , "&Iota;" => "Ι"
    , "&Kappa;" => "Κ"
    , "&Lambda;" => "Λ"
    , "&Mu;" => "Μ"
    , "&Nu;" => "Ν"
    , "&Xi;" => "Ξ"
    , "&Omicron;" => "Ο"
    , "&Pi;" => "Π"
    , "&Rho;" => "Ρ"
    , "&Sigma;" => "Σ"
    , "&Tau;" => "Τ"
    , "&Upsilon;" => "Υ"
    , "&Phi;" => "Φ"
    , "&Chi;" => "Χ"
    , "&Psi;" => "Ψ"
    , "&Omega;" => "Ω"
    , "&alpha;" => "α"
    , "&beta;" => "β"
    , "&gamma;" => "γ"
    , "&delta;" => "δ"
    , "&epsilon;" => "ε"
    , "&varepsilon;" => "ε"
    , "&epsiv;" => "ε"
    , "&zeta;" => "ζ"
    , "&eta;" => "η"
    , "&theta;" => "θ"
    , "&iota;" => "ι"
    , "&kappa;" => "κ"
    , "&lambda;" => "λ"
    , "&mu;" => "μ"
    , "&nu;" => "ν"
    , "&xi;" => "ξ"
    , "&omicron;" => "ο"
    , "&pi;" => "π"
    , "&rho;" => "ρ"
    , "&sigmaf;" => "ς"
    , "&varsigma;" => "ς"
    , "&sigmav;" => "ς"
    , "&sigma;" => "σ"
    , "&tau;" => "τ"
    , "&upsilon;" => "υ"
    , "&upsi;" => "υ"
    , "&varphi;" => "φ"
    , "&phiv;" => "φ"
    , "&phi;" => "φ"
    , "&chi;" => "χ"
    , "&psi;" => "ψ"
    , "&omega;" => "ω"
    , "&thetasym;" => "ϑ"
    , "&vartheta;" => "ϑ"
    , "&thetav;" => "ϑ"
    , "&upsih;" => "ϒ"
    , "&Upsi;" => "ϒ"
    , "&straightphi;" => "ϕ"
    , "&varpi;" => "ϖ"
    , "&piv;" => "ϖ"
    , "&Gammad;" => "Ϝ"
    , "&digamma;" => "ϝ"
    , "&gammad;" => "ϝ"
    , "&varkappa;" => "ϰ"
    , "&kappav;" => "ϰ"
    , "&varrho;" => "ϱ"
    , "&rhov;" => "ϱ"
    , "&straightepsilon;" => "ϵ"
    , "&epsi;" => "ϵ"
    , "&backepsilon;" => "϶"
    , "&bepsi;" => "϶"
    , "&IOcy;" => "Ё"
    , "&DJcy;" => "Ђ"
    , "&GJcy;" => "Ѓ"
    , "&Jukcy;" => "Є"
    , "&DScy;" => "Ѕ"
    , "&Iukcy;" => "І"
    , "&YIcy;" => "Ї"
    , "&Jsercy;" => "Ј"
    , "&LJcy;" => "Љ"
    , "&NJcy;" => "Њ"
    , "&TSHcy;" => "Ћ"
    , "&KJcy;" => "Ќ"
    , "&Ubrcy;" => "Ў"
    , "&DZcy;" => "Џ"
    , "&Acy;" => "А"
    , "&Bcy;" => "Б"
    , "&Vcy;" => "В"
    , "&Gcy;" => "Г"
    , "&Dcy;" => "Д"
    , "&IEcy;" => "Е"
    , "&ZHcy;" => "Ж"
    , "&Zcy;" => "З"
    , "&Icy;" => "И"
    , "&Jcy;" => "Й"
    , "&Kcy;" => "К"
    , "&Lcy;" => "Л"
    , "&Mcy;" => "М"
    , "&Ncy;" => "Н"
    , "&Ocy;" => "О"
    , "&Pcy;" => "П"
    , "&Rcy;" => "Р"
    , "&Scy;" => "С"
    , "&Tcy;" => "Т"
    , "&Ucy;" => "У"
    , "&Fcy;" => "Ф"
    , "&KHcy;" => "Х"
    , "&TScy;" => "Ц"
    , "&CHcy;" => "Ч"
    , "&SHcy;" => "Ш"
    , "&SHCHcy;" => "Щ"
    , "&HARDcy;" => "Ъ"
    , "&Ycy;" => "Ы"
    , "&SOFTcy;" => "Ь"
    , "&Ecy;" => "Э"
    , "&YUcy;" => "Ю"
    , "&YAcy;" => "Я"
    , "&acy;" => "а"
    , "&bcy;" => "б"
    , "&vcy;" => "в"
    , "&gcy;" => "г"
    , "&dcy;" => "д"
    , "&iecy;" => "е"
    , "&zhcy;" => "ж"
    , "&zcy;" => "з"
    , "&icy;" => "и"
    , "&jcy;" => "й"
    , "&kcy;" => "к"
    , "&lcy;" => "л"
    , "&mcy;" => "м"
    , "&ncy;" => "н"
    , "&ocy;" => "о"
    , "&pcy;" => "п"
    , "&rcy;" => "р"
    , "&scy;" => "с"
    , "&tcy;" => "т"
    , "&ucy;" => "у"
    , "&fcy;" => "ф"
    , "&khcy;" => "х"
    , "&tscy;" => "ц"
    , "&chcy;" => "ч"
    , "&shcy;" => "ш"
    , "&shchcy;" => "щ"
    , "&hardcy;" => "ъ"
    , "&ycy;" => "ы"
    , "&softcy;" => "ь"
    , "&ecy;" => "э"
    , "&yucy;" => "ю"
    , "&yacy;" => "я"
    , "&iocy;" => "ё"
    , "&djcy;" => "ђ"
    , "&gjcy;" => "ѓ"
    , "&jukcy;" => "є"
    , "&dscy;" => "ѕ"
    , "&iukcy;" => "і"
    , "&yicy;" => "ї"
    , "&jsercy;" => "ј"
    , "&ljcy;" => "љ"
    , "&njcy;" => "њ"
    , "&tshcy;" => "ћ"
    , "&kjcy;" => "ќ"
    , "&ubrcy;" => "ў"
    , "&dzcy;" => "џ"
    , "&ensp;" => "\x2002"
    , "&emsp;" => "\x2003"
    , "&emsp13;" => "\x2004"
    , "&emsp14;" => "\x2005"
    , "&numsp;" => "\x2007"
    , "&puncsp;" => "\x2008"
    , "&ThinSpace;" => "\x2009"
    , "&thinsp;" => "\x2009"
    , "&VeryThinSpace;" => "\x200A"
    , "&hairsp;" => "\x200A"
    , "&NegativeThickSpace;" => "\x200B"
    , "&NegativeMediumSpace;" => "\x200B"
    , "&NegativeThinSpace;" => "\x200B"
    , "&NegativeVeryThinSpace;" => "\x200B"
    , "&ZeroWidthSpace;" => "\x200B"
    , "&zwnj;" => "\x200C"
    , "&zwj;" => "\x200D"
    , "&lrm;" => "\x200E"
    , "&rlm;" => "\x200F"
    , "&dash;" => "‐"
    , "&hyphen;" => "‐"
    , "&ndash;" => "–"
    , "&mdash;" => "—"
    , "&horbar;" => "―"
    , "&Vert;" => "‖"
    , "&Verbar;" => "‖"
    , "&OpenCurlyQuote;" => "‘"
    , "&lsquo;" => "‘"
    , "&CloseCurlyQuote;" => "’"
    , "&rsquor;" => "’"
    , "&rsquo;" => "’"
    , "&sbquo;" => "‚"
    , "&lsquor;" => "‚"
    , "&OpenCurlyDoubleQuote;" => "“"
    , "&ldquo;" => "“"
    , "&CloseCurlyDoubleQuote;" => "”"
    , "&rdquor;" => "”"
    , "&rdquo;" => "”"
    , "&bdquo;" => "„"
    , "&ldquor;" => "„"
    , "&dagger;" => "†"
    , "&ddagger;" => "‡"
    , "&Dagger;" => "‡"
    , "&bullet;" => "•"
    , "&bull;" => "•"
    , "&nldr;" => "‥"
    , "&mldr;" => "…"
    , "&hellip;" => "…"
    , "&permil;" => "‰"
    , "&pertenk;" => "‱"
    , "&prime;" => "′"
    , "&Prime;" => "″"
    , "&tprime;" => "‴"
    , "&backprime;" => "‵"
    , "&bprime;" => "‵"
    , "&lsaquo;" => "‹"
    , "&rsaquo;" => "›"
    , "&oline;" => "‾"
    , "&caret;" => "⁁"
    , "&hybull;" => "⁃"
    , "&frasl;" => "⁄"
    , "&bsemi;" => "⁏"
    , "&qprime;" => "⁗"
    , "&MediumSpace;" => "\x205F"
    , "&NoBreak;" => "\x2060"
    , "&af;" => "\x2061"
    , "&ApplyFunction;" => "\x2061"
    , "&it;" => "\x2062"
    , "&InvisibleTimes;" => "\x2062"
    , "&ic;" => "\x2063"
    , "&InvisibleComma;" => "\x2063"
    , "&euro;" => "€"
    , "&TripleDot;" => "⃛"
    , "&tdot;" => "⃛"
    , "&DotDot;" => "⃜"
    , "&complexes;" => "ℂ"
    , "&Copf;" => "ℂ"
    , "&incare;" => "℅"
    , "&gscr;" => "ℊ"
    , "&Hscr;" => "ℋ"
    , "&HilbertSpace;" => "ℋ"
    , "&hamilt;" => "ℋ"
    , "&Poincareplane;" => "ℌ"
    , "&Hfr;" => "ℌ"
    , "&Hopf;" => "ℍ"
    , "&quaternions;" => "ℍ"
    , "&planckh;" => "ℎ"
    , "&hslash;" => "ℏ"
    , "&plankv;" => "ℏ"
    , "&hbar;" => "ℏ"
    , "&planck;" => "ℏ"
    , "&imagline;" => "ℐ"
    , "&Iscr;" => "ℐ"
    , "&Ifr;" => "ℑ"
    , "&imagpart;" => "ℑ"
    , "&Im;" => "ℑ"
    , "&image;" => "ℑ"
    , "&Laplacetrf;" => "ℒ"
    , "&lagran;" => "ℒ"
    , "&Lscr;" => "ℒ"
    , "&ell;" => "ℓ"
    , "&naturals;" => "ℕ"
    , "&Nopf;" => "ℕ"
    , "&numero;" => "№"
    , "&copysr;" => "℗"
    , "&wp;" => "℘"
    , "&weierp;" => "℘"
    , "&primes;" => "ℙ"
    , "&Popf;" => "ℙ"
    , "&Qopf;" => "ℚ"
    , "&rationals;" => "ℚ"
    , "&realine;" => "ℛ"
    , "&Rscr;" => "ℛ"
    , "&Rfr;" => "ℜ"
    , "&realpart;" => "ℜ"
    , "&Re;" => "ℜ"
    , "&real;" => "ℜ"
    , "&Ropf;" => "ℝ"
    , "&reals;" => "ℝ"
    , "&rx;" => "℞"
    , "&TRADE;" => "™"
    , "&trade;" => "™"
    , "&Zopf;" => "ℤ"
    , "&integers;" => "ℤ"
    , "&ohm;" => "Ω"
    , "&mho;" => "℧"
    , "&zeetrf;" => "ℨ"
    , "&Zfr;" => "ℨ"
    , "&iiota;" => "℩"
    , "&angst;" => "Å"
    , "&Bscr;" => "ℬ"
    , "&Bernoullis;" => "ℬ"
    , "&bernou;" => "ℬ"
    , "&Cayleys;" => "ℭ"
    , "&Cfr;" => "ℭ"
    , "&escr;" => "ℯ"
    , "&expectation;" => "ℰ"
    , "&Escr;" => "ℰ"
    , "&Fouriertrf;" => "ℱ"
    , "&Fscr;" => "ℱ"
    , "&Mscr;" => "ℳ"
    , "&Mellintrf;" => "ℳ"
    , "&phmmat;" => "ℳ"
    , "&oscr;" => "ℴ"
    , "&orderof;" => "ℴ"
    , "&order;" => "ℴ"
    , "&aleph;" => "ℵ"
    , "&alefsym;" => "ℵ"
    , "&beth;" => "ℶ"
    , "&gimel;" => "ℷ"
    , "&daleth;" => "ℸ"
    , "&DD;" => "ⅅ"
    , "&CapitalDifferentialD;" => "ⅅ"
    , "&dd;" => "ⅆ"
    , "&DifferentialD;" => "ⅆ"
    , "&ee;" => "ⅇ"
    , "&exponentiale;" => "ⅇ"
    , "&ExponentialE;" => "ⅇ"
    , "&ii;" => "ⅈ"
    , "&ImaginaryI;" => "ⅈ"
    , "&frac13;" => "⅓"
    , "&frac23;" => "⅔"
    , "&frac15;" => "⅕"
    , "&frac25;" => "⅖"
    , "&frac35;" => "⅗"
    , "&frac45;" => "⅘"
    , "&frac16;" => "⅙"
    , "&frac56;" => "⅚"
    , "&frac18;" => "⅛"
    , "&frac38;" => "⅜"
    , "&frac58;" => "⅝"
    , "&frac78;" => "⅞"
    , "&ShortLeftArrow;" => "←"
    , "&slarr;" => "←"
    , "&LeftArrow;" => "←"
    , "&leftarrow;" => "←"
    , "&larr;" => "←"
    , "&ShortUpArrow;" => "↑"
    , "&UpArrow;" => "↑"
    , "&uparrow;" => "↑"
    , "&uarr;" => "↑"
    , "&ShortRightArrow;" => "→"
    , "&srarr;" => "→"
    , "&RightArrow;" => "→"
    , "&rightarrow;" => "→"
    , "&rarr;" => "→"
    , "&ShortDownArrow;" => "↓"
    , "&DownArrow;" => "↓"
    , "&downarrow;" => "↓"
    , "&darr;" => "↓"
    , "&LeftRightArrow;" => "↔"
    , "&leftrightarrow;" => "↔"
    , "&harr;" => "↔"
    , "&UpDownArrow;" => "↕"
    , "&updownarrow;" => "↕"
    , "&varr;" => "↕"
    , "&nwarrow;" => "↖"
    , "&UpperLeftArrow;" => "↖"
    , "&nwarr;" => "↖"
    , "&nearrow;" => "↗"
    , "&UpperRightArrow;" => "↗"
    , "&nearr;" => "↗"
    , "&LowerRightArrow;" => "↘"
    , "&searrow;" => "↘"
    , "&searr;" => "↘"
    , "&LowerLeftArrow;" => "↙"
    , "&swarrow;" => "↙"
    , "&swarr;" => "↙"
    , "&nleftarrow;" => "↚"
    , "&nlarr;" => "↚"
    , "&nrightarrow;" => "↛"
    , "&nrarr;" => "↛"
    , "&rightsquigarrow;" => "↝"
    , "&rarrw;" => "↝"
    , "&twoheadleftarrow;" => "↞"
    , "&Larr;" => "↞"
    , "&Uarr;" => "↟"
    , "&twoheadrightarrow;" => "↠"
    , "&Rarr;" => "↠"
    , "&Darr;" => "↡"
    , "&leftarrowtail;" => "↢"
    , "&larrtl;" => "↢"
    , "&rightarrowtail;" => "↣"
    , "&rarrtl;" => "↣"
    , "&mapstoleft;" => "↤"
    , "&LeftTeeArrow;" => "↤"
    , "&mapstoup;" => "↥"
    , "&UpTeeArrow;" => "↥"
    , "&mapsto;" => "↦"
    , "&RightTeeArrow;" => "↦"
    , "&map;" => "↦"
    , "&mapstodown;" => "↧"
    , "&DownTeeArrow;" => "↧"
    , "&hookleftarrow;" => "↩"
    , "&larrhk;" => "↩"
    , "&hookrightarrow;" => "↪"
    , "&rarrhk;" => "↪"
    , "&looparrowleft;" => "↫"
    , "&larrlp;" => "↫"
    , "&looparrowright;" => "↬"
    , "&rarrlp;" => "↬"
    , "&leftrightsquigarrow;" => "↭"
    , "&harrw;" => "↭"
    , "&nleftrightarrow;" => "↮"
    , "&nharr;" => "↮"
    , "&Lsh;" => "↰"
    , "&lsh;" => "↰"
    , "&Rsh;" => "↱"
    , "&rsh;" => "↱"
    , "&ldsh;" => "↲"
    , "&rdsh;" => "↳"
    , "&crarr;" => "↵"
    , "&curvearrowleft;" => "↶"
    , "&cularr;" => "↶"
    , "&curvearrowright;" => "↷"
    , "&curarr;" => "↷"
    , "&circlearrowleft;" => "↺"
    , "&olarr;" => "↺"
    , "&circlearrowright;" => "↻"
    , "&orarr;" => "↻"
    , "&leftharpoonup;" => "↼"
    , "&LeftVector;" => "↼"
    , "&lharu;" => "↼"
    , "&DownLeftVector;" => "↽"
    , "&leftharpoondown;" => "↽"
    , "&lhard;" => "↽"
    , "&RightUpVector;" => "↾"
    , "&upharpoonright;" => "↾"
    , "&uharr;" => "↾"
    , "&LeftUpVector;" => "↿"
    , "&upharpoonleft;" => "↿"
    , "&uharl;" => "↿"
    , "&rightharpoonup;" => "⇀"
    , "&RightVector;" => "⇀"
    , "&rharu;" => "⇀"
    , "&DownRightVector;" => "⇁"
    , "&rightharpoondown;" => "⇁"
    , "&rhard;" => "⇁"
    , "&downharpoonright;" => "⇂"
    , "&RightDownVector;" => "⇂"
    , "&dharr;" => "⇂"
    , "&downharpoonleft;" => "⇃"
    , "&LeftDownVector;" => "⇃"
    , "&dharl;" => "⇃"
    , "&RightArrowLeftArrow;" => "⇄"
    , "&rightleftarrows;" => "⇄"
    , "&rlarr;" => "⇄"
    , "&UpArrowDownArrow;" => "⇅"
    , "&udarr;" => "⇅"
    , "&LeftArrowRightArrow;" => "⇆"
    , "&leftrightarrows;" => "⇆"
    , "&lrarr;" => "⇆"
    , "&leftleftarrows;" => "⇇"
    , "&llarr;" => "⇇"
    , "&upuparrows;" => "⇈"
    , "&uuarr;" => "⇈"
    , "&rightrightarrows;" => "⇉"
    , "&rrarr;" => "⇉"
    , "&downdownarrows;" => "⇊"
    , "&ddarr;" => "⇊"
    , "&leftrightharpoons;" => "⇋"
    , "&ReverseEquilibrium;" => "⇋"
    , "&lrhar;" => "⇋"
    , "&Equilibrium;" => "⇌"
    , "&rightleftharpoons;" => "⇌"
    , "&rlhar;" => "⇌"
    , "&nLeftarrow;" => "⇍"
    , "&nlArr;" => "⇍"
    , "&nLeftrightarrow;" => "⇎"
    , "&nhArr;" => "⇎"
    , "&nRightarrow;" => "⇏"
    , "&nrArr;" => "⇏"
    , "&DoubleLeftArrow;" => "⇐"
    , "&Leftarrow;" => "⇐"
    , "&lArr;" => "⇐"
    , "&DoubleUpArrow;" => "⇑"
    , "&Uparrow;" => "⇑"
    , "&uArr;" => "⇑"
    , "&DoubleRightArrow;" => "⇒"
    , "&Implies;" => "⇒"
    , "&Rightarrow;" => "⇒"
    , "&rArr;" => "⇒"
    , "&DoubleDownArrow;" => "⇓"
    , "&Downarrow;" => "⇓"
    , "&dArr;" => "⇓"
    , "&iff;" => "⇔"
    , "&DoubleLeftRightArrow;" => "⇔"
    , "&Leftrightarrow;" => "⇔"
    , "&hArr;" => "⇔"
    , "&DoubleUpDownArrow;" => "⇕"
    , "&Updownarrow;" => "⇕"
    , "&vArr;" => "⇕"
    , "&nwArr;" => "⇖"
    , "&neArr;" => "⇗"
    , "&seArr;" => "⇘"
    , "&swArr;" => "⇙"
    , "&Lleftarrow;" => "⇚"
    , "&lAarr;" => "⇚"
    , "&Rrightarrow;" => "⇛"
    , "&rAarr;" => "⇛"
    , "&zigrarr;" => "⇝"
    , "&LeftArrowBar;" => "⇤"
    , "&larrb;" => "⇤"
    , "&RightArrowBar;" => "⇥"
    , "&rarrb;" => "⇥"
    , "&DownArrowUpArrow;" => "⇵"
    , "&duarr;" => "⇵"
    , "&loarr;" => "⇽"
    , "&roarr;" => "⇾"
    , "&hoarr;" => "⇿"
    , "&ForAll;" => "∀"
    , "&forall;" => "∀"
    , "&complement;" => "∁"
    , "&comp;" => "∁"
    , "&PartialD;" => "∂"
    , "&part;" => "∂"
    , "&Exists;" => "∃"
    , "&exist;" => "∃"
    , "&nexists;" => "∄"
    , "&NotExists;" => "∄"
    , "&nexist;" => "∄"
    , "&varnothing;" => "∅"
    , "&emptyv;" => "∅"
    , "&emptyset;" => "∅"
    , "&empty;" => "∅"
    , "&Del;" => "∇"
    , "&nabla;" => "∇"
    , "&in;" => "∈"
    , "&Element;" => "∈"
    , "&isinv;" => "∈"
    , "&isin;" => "∈"
    , "&notinva;" => "∉"
    , "&NotElement;" => "∉"
    , "&notin;" => "∉"
    , "&SuchThat;" => "∋"
    , "&ni;" => "∋"
    , "&ReverseElement;" => "∋"
    , "&niv;" => "∋"
    , "&NotReverseElement;" => "∌"
    , "&notniva;" => "∌"
    , "&notni;" => "∌"
    , "&Product;" => "∏"
    , "&prod;" => "∏"
    , "&Coproduct;" => "∐"
    , "&coprod;" => "∐"
    , "&Sum;" => "∑"
    , "&sum;" => "∑"
    , "&minus;" => "−"
    , "&MinusPlus;" => "∓"
    , "&mp;" => "∓"
    , "&mnplus;" => "∓"
    , "&dotplus;" => "∔"
    , "&plusdo;" => "∔"
    , "&smallsetminus;" => "∖"
    , "&ssetmn;" => "∖"
    , "&Backslash;" => "∖"
    , "&setminus;" => "∖"
    , "&setmn;" => "∖"
    , "&lowast;" => "∗"
    , "&SmallCircle;" => "∘"
    , "&compfn;" => "∘"
    , "&Sqrt;" => "√"
    , "&radic;" => "√"
    , "&varpropto;" => "∝"
    , "&vprop;" => "∝"
    , "&Proportional;" => "∝"
    , "&propto;" => "∝"
    , "&prop;" => "∝"
    , "&infin;" => "∞"
    , "&angrt;" => "∟"
    , "&angle;" => "∠"
    , "&ang;" => "∠"
    , "&measuredangle;" => "∡"
    , "&angmsd;" => "∡"
    , "&angsph;" => "∢"
    , "&shortmid;" => "∣"
    , "&smid;" => "∣"
    , "&VerticalBar;" => "∣"
    , "&mid;" => "∣"
    , "&nshortmid;" => "∤"
    , "&nsmid;" => "∤"
    , "&NotVerticalBar;" => "∤"
    , "&nmid;" => "∤"
    , "&shortparallel;" => "∥"
    , "&spar;" => "∥"
    , "&DoubleVerticalBar;" => "∥"
    , "&parallel;" => "∥"
    , "&par;" => "∥"
    , "&nshortparallel;" => "∦"
    , "&nspar;" => "∦"
    , "&NotDoubleVerticalBar;" => "∦"
    , "&nparallel;" => "∦"
    , "&npar;" => "∦"
    , "&wedge;" => "∧"
    , "&and;" => "∧"
    , "&vee;" => "∨"
    , "&or;" => "∨"
    , "&cap;" => "∩"
    , "&cup;" => "∪"
    , "&Integral;" => "∫"
    , "&int;" => "∫"
    , "&Int;" => "∬"
    , "&iiint;" => "∭"
    , "&tint;" => "∭"
    , "&ContourIntegral;" => "∮"
    , "&oint;" => "∮"
    , "&conint;" => "∮"
    , "&DoubleContourIntegral;" => "∯"
    , "&Conint;" => "∯"
    , "&Cconint;" => "∰"
    , "&cwint;" => "∱"
    , "&ClockwiseContourIntegral;" => "∲"
    , "&cwconint;" => "∲"
    , "&CounterClockwiseContourIntegral;" => "∳"
    , "&awconint;" => "∳"
    , "&Therefore;" => "∴"
    , "&therefore;" => "∴"
    , "&there4;" => "∴"
    , "&Because;" => "∵"
    , "&because;" => "∵"
    , "&becaus;" => "∵"
    , "&ratio;" => "∶"
    , "&Proportion;" => "∷"
    , "&Colon;" => "∷"
    , "&dotminus;" => "∸"
    , "&minusd;" => "∸"
    , "&mDDot;" => "∺"
    , "&homtht;" => "∻"
    , "&thicksim;" => "∼"
    , "&thksim;" => "∼"
    , "&Tilde;" => "∼"
    , "&sim;" => "∼"
    , "&backsim;" => "∽"
    , "&bsim;" => "∽"
    , "&mstpos;" => "∾"
    , "&ac;" => "∾"
    , "&acd;" => "∿"
    , "&wr;" => "≀"
    , "&VerticalTilde;" => "≀"
    , "&wreath;" => "≀"
    , "&NotTilde;" => "≁"
    , "&nsim;" => "≁"
    , "&eqsim;" => "≂"
    , "&EqualTilde;" => "≂"
    , "&esim;" => "≂"
    , "&simeq;" => "≃"
    , "&TildeEqual;" => "≃"
    , "&sime;" => "≃"
    , "&NotTildeEqual;" => "≄"
    , "&nsimeq;" => "≄"
    , "&nsime;" => "≄"
    , "&TildeFullEqual;" => "≅"
    , "&cong;" => "≅"
    , "&simne;" => "≆"
    , "&NotTildeFullEqual;" => "≇"
    , "&ncong;" => "≇"
    , "&thickapprox;" => "≈"
    , "&thkap;" => "≈"
    , "&approx;" => "≈"
    , "&TildeTilde;" => "≈"
    , "&ap;" => "≈"
    , "&asymp;" => "≈"
    , "&napprox;" => "≉"
    , "&NotTildeTilde;" => "≉"
    , "&nap;" => "≉"
    , "&approxeq;" => "≊"
    , "&ape;" => "≊"
    , "&apid;" => "≋"
    , "&backcong;" => "≌"
    , "&bcong;" => "≌"
    , "&CupCap;" => "≍"
    , "&asympeq;" => "≍"
    , "&Bumpeq;" => "≎"
    , "&HumpDownHump;" => "≎"
    , "&bump;" => "≎"
    , "&bumpeq;" => "≏"
    , "&HumpEqual;" => "≏"
    , "&bumpe;" => "≏"
    , "&doteq;" => "≐"
    , "&DotEqual;" => "≐"
    , "&esdot;" => "≐"
    , "&doteqdot;" => "≑"
    , "&eDot;" => "≑"
    , "&fallingdotseq;" => "≒"
    , "&efDot;" => "≒"
    , "&risingdotseq;" => "≓"
    , "&erDot;" => "≓"
    , "&Assign;" => "≔"
    , "&coloneq;" => "≔"
    , "&colone;" => "≔"
    , "&eqcolon;" => "≕"
    , "&ecolon;" => "≕"
    , "&eqcirc;" => "≖"
    , "&ecir;" => "≖"
    , "&circeq;" => "≗"
    , "&cire;" => "≗"
    , "&wedgeq;" => "≙"
    , "&veeeq;" => "≚"
    , "&triangleq;" => "≜"
    , "&trie;" => "≜"
    , "&questeq;" => "≟"
    , "&equest;" => "≟"
    , "&NotEqual;" => "≠"
    , "&ne;" => "≠"
    , "&Congruent;" => "≡"
    , "&equiv;" => "≡"
    , "&NotCongruent;" => "≢"
    , "&nequiv;" => "≢"
    , "&leq;" => "≤"
    , "&le;" => "≤"
    , "&geq;" => "≥"
    , "&GreaterEqual;" => "≥"
    , "&ge;" => "≥"
    , "&leqq;" => "≦"
    , "&LessFullEqual;" => "≦"
    , "&lE;" => "≦"
    , "&geqq;" => "≧"
    , "&GreaterFullEqual;" => "≧"
    , "&gE;" => "≧"
    , "&lneqq;" => "≨"
    , "&lnE;" => "≨"
    , "&gneqq;" => "≩"
    , "&gnE;" => "≩"
    , "&ll;" => "≪"
    , "&NestedLessLess;" => "≪"
    , "&Lt;" => "≪"
    , "&gg;" => "≫"
    , "&NestedGreaterGreater;" => "≫"
    , "&Gt;" => "≫"
    , "&between;" => "≬"
    , "&twixt;" => "≬"
    , "&NotCupCap;" => "≭"
    , "&nless;" => "≮"
    , "&NotLess;" => "≮"
    , "&nlt;" => "≮"
    , "&ngtr;" => "≯"
    , "&NotGreater;" => "≯"
    , "&ngt;" => "≯"
    , "&nleq;" => "≰"
    , "&NotLessEqual;" => "≰"
    , "&nle;" => "≰"
    , "&ngeq;" => "≱"
    , "&NotGreaterEqual;" => "≱"
    , "&nge;" => "≱"
    , "&lesssim;" => "≲"
    , "&LessTilde;" => "≲"
    , "&lsim;" => "≲"
    , "&GreaterTilde;" => "≳"
    , "&gtrsim;" => "≳"
    , "&gsim;" => "≳"
    , "&NotLessTilde;" => "≴"
    , "&nlsim;" => "≴"
    , "&NotGreaterTilde;" => "≵"
    , "&ngsim;" => "≵"
    , "&LessGreater;" => "≶"
    , "&lessgtr;" => "≶"
    , "&lg;" => "≶"
    , "&GreaterLess;" => "≷"
    , "&gtrless;" => "≷"
    , "&gl;" => "≷"
    , "&NotLessGreater;" => "≸"
    , "&ntlg;" => "≸"
    , "&NotGreaterLess;" => "≹"
    , "&ntgl;" => "≹"
    , "&prec;" => "≺"
    , "&Precedes;" => "≺"
    , "&pr;" => "≺"
    , "&succ;" => "≻"
    , "&Succeeds;" => "≻"
    , "&sc;" => "≻"
    , "&preccurlyeq;" => "≼"
    , "&PrecedesSlantEqual;" => "≼"
    , "&prcue;" => "≼"
    , "&succcurlyeq;" => "≽"
    , "&SucceedsSlantEqual;" => "≽"
    , "&sccue;" => "≽"
    , "&PrecedesTilde;" => "≾"
    , "&precsim;" => "≾"
    , "&prsim;" => "≾"
    , "&SucceedsTilde;" => "≿"
    , "&succsim;" => "≿"
    , "&scsim;" => "≿"
    , "&NotPrecedes;" => "⊀"
    , "&nprec;" => "⊀"
    , "&npr;" => "⊀"
    , "&NotSucceeds;" => "⊁"
    , "&nsucc;" => "⊁"
    , "&nsc;" => "⊁"
    , "&subset;" => "⊂"
    , "&sub;" => "⊂"
    , "&Superset;" => "⊃"
    , "&supset;" => "⊃"
    , "&sup;" => "⊃"
    , "&nsub;" => "⊄"
    , "&nsup;" => "⊅"
    , "&subseteq;" => "⊆"
    , "&SubsetEqual;" => "⊆"
    , "&sube;" => "⊆"
    , "&SupersetEqual;" => "⊇"
    , "&supseteq;" => "⊇"
    , "&supe;" => "⊇"
    , "&NotSubsetEqual;" => "⊈"
    , "&nsubseteq;" => "⊈"
    , "&nsube;" => "⊈"
    , "&NotSupersetEqual;" => "⊉"
    , "&nsupseteq;" => "⊉"
    , "&nsupe;" => "⊉"
    , "&subsetneq;" => "⊊"
    , "&subne;" => "⊊"
    , "&supsetneq;" => "⊋"
    , "&supne;" => "⊋"
    , "&cupdot;" => "⊍"
    , "&UnionPlus;" => "⊎"
    , "&uplus;" => "⊎"
    , "&sqsubset;" => "⊏"
    , "&SquareSubset;" => "⊏"
    , "&sqsub;" => "⊏"
    , "&sqsupset;" => "⊐"
    , "&SquareSuperset;" => "⊐"
    , "&sqsup;" => "⊐"
    , "&sqsubseteq;" => "⊑"
    , "&SquareSubsetEqual;" => "⊑"
    , "&sqsube;" => "⊑"
    , "&sqsupseteq;" => "⊒"
    , "&SquareSupersetEqual;" => "⊒"
    , "&sqsupe;" => "⊒"
    , "&SquareIntersection;" => "⊓"
    , "&sqcap;" => "⊓"
    , "&SquareUnion;" => "⊔"
    , "&sqcup;" => "⊔"
    , "&CirclePlus;" => "⊕"
    , "&oplus;" => "⊕"
    , "&CircleMinus;" => "⊖"
    , "&ominus;" => "⊖"
    , "&CircleTimes;" => "⊗"
    , "&otimes;" => "⊗"
    , "&osol;" => "⊘"
    , "&CircleDot;" => "⊙"
    , "&odot;" => "⊙"
    , "&circledcirc;" => "⊚"
    , "&ocir;" => "⊚"
    , "&circledast;" => "⊛"
    , "&oast;" => "⊛"
    , "&circleddash;" => "⊝"
    , "&odash;" => "⊝"
    , "&boxplus;" => "⊞"
    , "&plusb;" => "⊞"
    , "&boxminus;" => "⊟"
    , "&minusb;" => "⊟"
    , "&boxtimes;" => "⊠"
    , "&timesb;" => "⊠"
    , "&dotsquare;" => "⊡"
    , "&sdotb;" => "⊡"
    , "&RightTee;" => "⊢"
    , "&vdash;" => "⊢"
    , "&LeftTee;" => "⊣"
    , "&dashv;" => "⊣"
    , "&DownTee;" => "⊤"
    , "&top;" => "⊤"
    , "&UpTee;" => "⊥"
    , "&perp;" => "⊥"
    , "&bot;" => "⊥"
    , "&bottom;" => "⊥"
    , "&models;" => "⊧"
    , "&DoubleRightTee;" => "⊨"
    , "&vDash;" => "⊨"
    , "&Vdash;" => "⊩"
    , "&Vvdash;" => "⊪"
    , "&VDash;" => "⊫"
    , "&nvdash;" => "⊬"
    , "&nvDash;" => "⊭"
    , "&nVdash;" => "⊮"
    , "&nVDash;" => "⊯"
    , "&prurel;" => "⊰"
    , "&LeftTriangle;" => "⊲"
    , "&vartriangleleft;" => "⊲"
    , "&vltri;" => "⊲"
    , "&RightTriangle;" => "⊳"
    , "&vartriangleright;" => "⊳"
    , "&vrtri;" => "⊳"
    , "&LeftTriangleEqual;" => "⊴"
    , "&trianglelefteq;" => "⊴"
    , "&ltrie;" => "⊴"
    , "&RightTriangleEqual;" => "⊵"
    , "&trianglerighteq;" => "⊵"
    , "&rtrie;" => "⊵"
    , "&origof;" => "⊶"
    , "&imof;" => "⊷"
    , "&multimap;" => "⊸"
    , "&mumap;" => "⊸"
    , "&hercon;" => "⊹"
    , "&intercal;" => "⊺"
    , "&intcal;" => "⊺"
    , "&veebar;" => "⊻"
    , "&barvee;" => "⊽"
    , "&angrtvb;" => "⊾"
    , "&lrtri;" => "⊿"
    , "&bigwedge;" => "⋀"
    , "&Wedge;" => "⋀"
    , "&xwedge;" => "⋀"
    , "&bigvee;" => "⋁"
    , "&Vee;" => "⋁"
    , "&xvee;" => "⋁"
    , "&bigcap;" => "⋂"
    , "&Intersection;" => "⋂"
    , "&xcap;" => "⋂"
    , "&bigcup;" => "⋃"
    , "&Union;" => "⋃"
    , "&xcup;" => "⋃"
    , "&Diamond;" => "⋄"
    , "&diamond;" => "⋄"
    , "&diam;" => "⋄"
    , "&sdot;" => "⋅"
    , "&Star;" => "⋆"
    , "&sstarf;" => "⋆"
    , "&divideontimes;" => "⋇"
    , "&divonx;" => "⋇"
    , "&bowtie;" => "⋈"
    , "&ltimes;" => "⋉"
    , "&rtimes;" => "⋊"
    , "&leftthreetimes;" => "⋋"
    , "&lthree;" => "⋋"
    , "&rightthreetimes;" => "⋌"
    , "&rthree;" => "⋌"
    , "&backsimeq;" => "⋍"
    , "&bsime;" => "⋍"
    , "&curlyvee;" => "⋎"
    , "&cuvee;" => "⋎"
    , "&curlywedge;" => "⋏"
    , "&cuwed;" => "⋏"
    , "&Subset;" => "⋐"
    , "&Sub;" => "⋐"
    , "&Supset;" => "⋑"
    , "&Sup;" => "⋑"
    , "&Cap;" => "⋒"
    , "&Cup;" => "⋓"
    , "&pitchfork;" => "⋔"
    , "&fork;" => "⋔"
    , "&epar;" => "⋕"
    , "&lessdot;" => "⋖"
    , "&ltdot;" => "⋖"
    , "&gtrdot;" => "⋗"
    , "&gtdot;" => "⋗"
    , "&Ll;" => "⋘"
    , "&ggg;" => "⋙"
    , "&Gg;" => "⋙"
    , "&lesseqgtr;" => "⋚"
    , "&LessEqualGreater;" => "⋚"
    , "&leg;" => "⋚"
    , "&GreaterEqualLess;" => "⋛"
    , "&gtreqless;" => "⋛"
    , "&gel;" => "⋛"
    , "&curlyeqprec;" => "⋞"
    , "&cuepr;" => "⋞"
    , "&curlyeqsucc;" => "⋟"
    , "&cuesc;" => "⋟"
    , "&NotPrecedesSlantEqual;" => "⋠"
    , "&nprcue;" => "⋠"
    , "&NotSucceedsSlantEqual;" => "⋡"
    , "&nsccue;" => "⋡"
    , "&NotSquareSubsetEqual;" => "⋢"
    , "&nsqsube;" => "⋢"
    , "&NotSquareSupersetEqual;" => "⋣"
    , "&nsqsupe;" => "⋣"
    , "&lnsim;" => "⋦"
    , "&gnsim;" => "⋧"
    , "&precnsim;" => "⋨"
    , "&prnsim;" => "⋨"
    , "&succnsim;" => "⋩"
    , "&scnsim;" => "⋩"
    , "&NotLeftTriangle;" => "⋪"
    , "&ntriangleleft;" => "⋪"
    , "&nltri;" => "⋪"
    , "&NotRightTriangle;" => "⋫"
    , "&ntriangleright;" => "⋫"
    , "&nrtri;" => "⋫"
    , "&NotLeftTriangleEqual;" => "⋬"
    , "&ntrianglelefteq;" => "⋬"
    , "&nltrie;" => "⋬"
    , "&NotRightTriangleEqual;" => "⋭"
    , "&ntrianglerighteq;" => "⋭"
    , "&nrtrie;" => "⋭"
    , "&vellip;" => "⋮"
    , "&ctdot;" => "⋯"
    , "&utdot;" => "⋰"
    , "&dtdot;" => "⋱"
    , "&disin;" => "⋲"
    , "&isinsv;" => "⋳"
    , "&isins;" => "⋴"
    , "&isindot;" => "⋵"
    , "&notinvc;" => "⋶"
    , "&notinvb;" => "⋷"
    , "&isinE;" => "⋹"
    , "&nisd;" => "⋺"
    , "&xnis;" => "⋻"
    , "&nis;" => "⋼"
    , "&notnivc;" => "⋽"
    , "&notnivb;" => "⋾"
    , "&barwedge;" => "⌅"
    , "&barwed;" => "⌅"
    , "&doublebarwedge;" => "⌆"
    , "&Barwed;" => "⌆"
    , "&LeftCeiling;" => "⌈"
    , "&lceil;" => "⌈"
    , "&RightCeiling;" => "⌉"
    , "&rceil;" => "⌉"
    , "&LeftFloor;" => "⌊"
    , "&lfloor;" => "⌊"
    , "&RightFloor;" => "⌋"
    , "&rfloor;" => "⌋"
    , "&drcrop;" => "⌌"
    , "&dlcrop;" => "⌍"
    , "&urcrop;" => "⌎"
    , "&ulcrop;" => "⌏"
    , "&bnot;" => "⌐"
    , "&profline;" => "⌒"
    , "&profsurf;" => "⌓"
    , "&telrec;" => "⌕"
    , "&target;" => "⌖"
    , "&ulcorner;" => "⌜"
    , "&ulcorn;" => "⌜"
    , "&urcorner;" => "⌝"
    , "&urcorn;" => "⌝"
    , "&llcorner;" => "⌞"
    , "&dlcorn;" => "⌞"
    , "&lrcorner;" => "⌟"
    , "&drcorn;" => "⌟"
    , "&sfrown;" => "⌢"
    , "&frown;" => "⌢"
    , "&ssmile;" => "⌣"
    , "&smile;" => "⌣"
    , "&cylcty;" => "⌭"
    , "&profalar;" => "⌮"
    , "&topbot;" => "⌶"
    , "&ovbar;" => "⌽"
    , "&solbar;" => "⌿"
    , "&angzarr;" => "⍼"
    , "&lmoustache;" => "⎰"
    , "&lmoust;" => "⎰"
    , "&rmoustache;" => "⎱"
    , "&rmoust;" => "⎱"
    , "&OverBracket;" => "⎴"
    , "&tbrk;" => "⎴"
    , "&UnderBracket;" => "⎵"
    , "&bbrk;" => "⎵"
    , "&bbrktbrk;" => "⎶"
    , "&OverParenthesis;" => "⏜"
    , "&UnderParenthesis;" => "⏝"
    , "&OverBrace;" => "⏞"
    , "&UnderBrace;" => "⏟"
    , "&trpezium;" => "⏢"
    , "&elinters;" => "⏧"
    , "&blank;" => "␣"
    , "&circledS;" => "Ⓢ"
    , "&oS;" => "Ⓢ"
    , "&HorizontalLine;" => "─"
    , "&boxh;" => "─"
    , "&boxv;" => "│"
    , "&boxdr;" => "┌"
    , "&boxdl;" => "┐"
    , "&boxur;" => "└"
    , "&boxul;" => "┘"
    , "&boxvr;" => "├"
    , "&boxvl;" => "┤"
    , "&boxhd;" => "┬"
    , "&boxhu;" => "┴"
    , "&boxvh;" => "┼"
    , "&boxH;" => "═"
    , "&boxV;" => "║"
    , "&boxdR;" => "╒"
    , "&boxDr;" => "╓"
    , "&boxDR;" => "╔"
    , "&boxdL;" => "╕"
    , "&boxDl;" => "╖"
    , "&boxDL;" => "╗"
    , "&boxuR;" => "╘"
    , "&boxUr;" => "╙"
    , "&boxUR;" => "╚"
    , "&boxuL;" => "╛"
    , "&boxUl;" => "╜"
    , "&boxUL;" => "╝"
    , "&boxvR;" => "╞"
    , "&boxVr;" => "╟"
    , "&boxVR;" => "╠"
    , "&boxvL;" => "╡"
    , "&boxVl;" => "╢"
    , "&boxVL;" => "╣"
    , "&boxHd;" => "╤"
    , "&boxhD;" => "╥"
    , "&boxHD;" => "╦"
    , "&boxHu;" => "╧"
    , "&boxhU;" => "╨"
    , "&boxHU;" => "╩"
    , "&boxvH;" => "╪"
    , "&boxVh;" => "╫"
    , "&boxVH;" => "╬"
    , "&uhblk;" => "▀"
    , "&lhblk;" => "▄"
    , "&block;" => "█"
    , "&blk14;" => "░"
    , "&blk12;" => "▒"
    , "&blk34;" => "▓"
    , "&Square;" => "□"
    , "&square;" => "□"
    , "&squ;" => "□"
    , "&FilledVerySmallSquare;" => "▪"
    , "&blacksquare;" => "▪"
    , "&squarf;" => "▪"
    , "&squf;" => "▪"
    , "&EmptyVerySmallSquare;" => "▫"
    , "&rect;" => "▭"
    , "&marker;" => "▮"
    , "&fltns;" => "▱"
    , "&bigtriangleup;" => "△"
    , "&xutri;" => "△"
    , "&blacktriangle;" => "▴"
    , "&utrif;" => "▴"
    , "&triangle;" => "▵"
    , "&utri;" => "▵"
    , "&blacktriangleright;" => "▸"
    , "&rtrif;" => "▸"
    , "&triangleright;" => "▹"
    , "&rtri;" => "▹"
    , "&bigtriangledown;" => "▽"
    , "&xdtri;" => "▽"
    , "&blacktriangledown;" => "▾"
    , "&dtrif;" => "▾"
    , "&triangledown;" => "▿"
    , "&dtri;" => "▿"
    , "&blacktriangleleft;" => "◂"
    , "&ltrif;" => "◂"
    , "&triangleleft;" => "◃"
    , "&ltri;" => "◃"
    , "&lozenge;" => "◊"
    , "&loz;" => "◊"
    , "&cir;" => "○"
    , "&tridot;" => "◬"
    , "&bigcirc;" => "◯"
    , "&xcirc;" => "◯"
    , "&ultri;" => "◸"
    , "&urtri;" => "◹"
    , "&lltri;" => "◺"
    , "&EmptySmallSquare;" => "◻"
    , "&FilledSmallSquare;" => "◼"
    , "&bigstar;" => "★"
    , "&starf;" => "★"
    , "&star;" => "☆"
    , "&phone;" => "☎"
    , "&female;" => "♀"
    , "&male;" => "♂"
    , "&spadesuit;" => "♠"
    , "&spades;" => "♠"
    , "&clubsuit;" => "♣"
    , "&clubs;" => "♣"
    , "&heartsuit;" => "♥"
    , "&hearts;" => "♥"
    , "&diamondsuit;" => "♦"
    , "&diams;" => "♦"
    , "&sung;" => "♪"
    , "&flat;" => "♭"
    , "&natural;" => "♮"
    , "&natur;" => "♮"
    , "&sharp;" => "♯"
    , "&checkmark;" => "✓"
    , "&check;" => "✓"
    , "&cross;" => "✗"
    , "&maltese;" => "✠"
    , "&malt;" => "✠"
    , "&sext;" => "✶"
    , "&VerticalSeparator;" => "❘"
    , "&lbbrk;" => "❲"
    , "&rbbrk;" => "❳"
    , "&LeftDoubleBracket;" => "⟦"
    , "&lobrk;" => "⟦"
    , "&RightDoubleBracket;" => "⟧"
    , "&robrk;" => "⟧"
    , "&langle;" => "⟨"
    , "&LeftAngleBracket;" => "⟨"
    , "&lang;" => "⟨"
    , "&rangle;" => "⟩"
    , "&RightAngleBracket;" => "⟩"
    , "&rang;" => "⟩"
    , "&Lang;" => "⟪"
    , "&Rang;" => "⟫"
    , "&loang;" => "⟬"
    , "&roang;" => "⟭"
    , "&LongLeftArrow;" => "⟵"
    , "&longleftarrow;" => "⟵"
    , "&xlarr;" => "⟵"
    , "&LongRightArrow;" => "⟶"
    , "&longrightarrow;" => "⟶"
    , "&xrarr;" => "⟶"
    , "&LongLeftRightArrow;" => "⟷"
    , "&longleftrightarrow;" => "⟷"
    , "&xharr;" => "⟷"
    , "&DoubleLongLeftArrow;" => "⟸"
    , "&Longleftarrow;" => "⟸"
    , "&xlArr;" => "⟸"
    , "&DoubleLongRightArrow;" => "⟹"
    , "&Longrightarrow;" => "⟹"
    , "&xrArr;" => "⟹"
    , "&DoubleLongLeftRightArrow;" => "⟺"
    , "&Longleftrightarrow;" => "⟺"
    , "&xhArr;" => "⟺"
    , "&longmapsto;" => "⟼"
    , "&xmap;" => "⟼"
    , "&dzigrarr;" => "⟿"
    , "&nvlArr;" => "⤂"
    , "&nvrArr;" => "⤃"
    , "&nvHarr;" => "⤄"
    , "&Map;" => "⤅"
    , "&lbarr;" => "⤌"
    , "&bkarow;" => "⤍"
    , "&rbarr;" => "⤍"
    , "&lBarr;" => "⤎"
    , "&dbkarow;" => "⤏"
    , "&rBarr;" => "⤏"
    , "&drbkarow;" => "⤐"
    , "&RBarr;" => "⤐"
    , "&DDotrahd;" => "⤑"
    , "&UpArrowBar;" => "⤒"
    , "&DownArrowBar;" => "⤓"
    , "&Rarrtl;" => "⤖"
    , "&latail;" => "⤙"
    , "&ratail;" => "⤚"
    , "&lAtail;" => "⤛"
    , "&rAtail;" => "⤜"
    , "&larrfs;" => "⤝"
    , "&rarrfs;" => "⤞"
    , "&larrbfs;" => "⤟"
    , "&rarrbfs;" => "⤠"
    , "&nwarhk;" => "⤣"
    , "&nearhk;" => "⤤"
    , "&hksearow;" => "⤥"
    , "&searhk;" => "⤥"
    , "&hkswarow;" => "⤦"
    , "&swarhk;" => "⤦"
    , "&nwnear;" => "⤧"
    , "&toea;" => "⤨"
    , "&nesear;" => "⤨"
    , "&tosa;" => "⤩"
    , "&seswar;" => "⤩"
    , "&swnwar;" => "⤪"
    , "&rarrc;" => "⤳"
    , "&cudarrr;" => "⤵"
    , "&ldca;" => "⤶"
    , "&rdca;" => "⤷"
    , "&cudarrl;" => "⤸"
    , "&larrpl;" => "⤹"
    , "&curarrm;" => "⤼"
    , "&cularrp;" => "⤽"
    , "&rarrpl;" => "⥅"
    , "&harrcir;" => "⥈"
    , "&Uarrocir;" => "⥉"
    , "&lurdshar;" => "⥊"
    , "&ldrushar;" => "⥋"
    , "&LeftRightVector;" => "⥎"
    , "&RightUpDownVector;" => "⥏"
    , "&DownLeftRightVector;" => "⥐"
    , "&LeftUpDownVector;" => "⥑"
    , "&LeftVectorBar;" => "⥒"
    , "&RightVectorBar;" => "⥓"
    , "&RightUpVectorBar;" => "⥔"
    , "&RightDownVectorBar;" => "⥕"
    , "&DownLeftVectorBar;" => "⥖"
    , "&DownRightVectorBar;" => "⥗"
    , "&LeftUpVectorBar;" => "⥘"
    , "&LeftDownVectorBar;" => "⥙"
    , "&LeftTeeVector;" => "⥚"
    , "&RightTeeVector;" => "⥛"
    , "&RightUpTeeVector;" => "⥜"
    , "&RightDownTeeVector;" => "⥝"
    , "&DownLeftTeeVector;" => "⥞"
    , "&DownRightTeeVector;" => "⥟"
    , "&LeftUpTeeVector;" => "⥠"
    , "&LeftDownTeeVector;" => "⥡"
    , "&lHar;" => "⥢"
    , "&uHar;" => "⥣"
    , "&rHar;" => "⥤"
    , "&dHar;" => "⥥"
    , "&luruhar;" => "⥦"
    , "&ldrdhar;" => "⥧"
    , "&ruluhar;" => "⥨"
    , "&rdldhar;" => "⥩"
    , "&lharul;" => "⥪"
    , "&llhard;" => "⥫"
    , "&rharul;" => "⥬"
    , "&lrhard;" => "⥭"
    , "&UpEquilibrium;" => "⥮"
    , "&udhar;" => "⥮"
    , "&ReverseUpEquilibrium;" => "⥯"
    , "&duhar;" => "⥯"
    , "&RoundImplies;" => "⥰"
    , "&erarr;" => "⥱"
    , "&simrarr;" => "⥲"
    , "&larrsim;" => "⥳"
    , "&rarrsim;" => "⥴"
    , "&rarrap;" => "⥵"
    , "&ltlarr;" => "⥶"
    , "&gtrarr;" => "⥸"
    , "&subrarr;" => "⥹"
    , "&suplarr;" => "⥻"
    , "&lfisht;" => "⥼"
    , "&rfisht;" => "⥽"
    , "&ufisht;" => "⥾"
    , "&dfisht;" => "⥿"
    , "&lopar;" => "⦅"
    , "&ropar;" => "⦆"
    , "&lbrke;" => "⦋"
    , "&rbrke;" => "⦌"
    , "&lbrkslu;" => "⦍"
    , "&rbrksld;" => "⦎"
    , "&lbrksld;" => "⦏"
    , "&rbrkslu;" => "⦐"
    , "&langd;" => "⦑"
    , "&rangd;" => "⦒"
    , "&lparlt;" => "⦓"
    , "&rpargt;" => "⦔"
    , "&gtlPar;" => "⦕"
    , "&ltrPar;" => "⦖"
    , "&vzigzag;" => "⦚"
    , "&vangrt;" => "⦜"
    , "&angrtvbd;" => "⦝"
    , "&ange;" => "⦤"
    , "&range;" => "⦥"
    , "&dwangle;" => "⦦"
    , "&uwangle;" => "⦧"
    , "&angmsdaa;" => "⦨"
    , "&angmsdab;" => "⦩"
    , "&angmsdac;" => "⦪"
    , "&angmsdad;" => "⦫"
    , "&angmsdae;" => "⦬"
    , "&angmsdaf;" => "⦭"
    , "&angmsdag;" => "⦮"
    , "&angmsdah;" => "⦯"
    , "&bemptyv;" => "⦰"
    , "&demptyv;" => "⦱"
    , "&cemptyv;" => "⦲"
    , "&raemptyv;" => "⦳"
    , "&laemptyv;" => "⦴"
    , "&ohbar;" => "⦵"
    , "&omid;" => "⦶"
    , "&opar;" => "⦷"
    , "&operp;" => "⦹"
    , "&olcross;" => "⦻"
    , "&odsold;" => "⦼"
    , "&olcir;" => "⦾"
    , "&ofcir;" => "⦿"
    , "&olt;" => "⧀"
    , "&ogt;" => "⧁"
    , "&cirscir;" => "⧂"
    , "&cirE;" => "⧃"
    , "&solb;" => "⧄"
    , "&bsolb;" => "⧅"
    , "&boxbox;" => "⧉"
    , "&trisb;" => "⧍"
    , "&rtriltri;" => "⧎"
    , "&LeftTriangleBar;" => "⧏"
    , "&RightTriangleBar;" => "⧐"
    , "&race;" => "⧚"
    , "&iinfin;" => "⧜"
    , "&infintie;" => "⧝"
    , "&nvinfin;" => "⧞"
    , "&eparsl;" => "⧣"
    , "&smeparsl;" => "⧤"
    , "&eqvparsl;" => "⧥"
    , "&blacklozenge;" => "⧫"
    , "&lozf;" => "⧫"
    , "&RuleDelayed;" => "⧴"
    , "&dsol;" => "⧶"
    , "&bigodot;" => "⨀"
    , "&xodot;" => "⨀"
    , "&bigoplus;" => "⨁"
    , "&xoplus;" => "⨁"
    , "&bigotimes;" => "⨂"
    , "&xotime;" => "⨂"
    , "&biguplus;" => "⨄"
    , "&xuplus;" => "⨄"
    , "&bigsqcup;" => "⨆"
    , "&xsqcup;" => "⨆"
    , "&iiiint;" => "⨌"
    , "&qint;" => "⨌"
    , "&fpartint;" => "⨍"
    , "&cirfnint;" => "⨐"
    , "&awint;" => "⨑"
    , "&rppolint;" => "⨒"
    , "&scpolint;" => "⨓"
    , "&npolint;" => "⨔"
    , "&pointint;" => "⨕"
    , "&quatint;" => "⨖"
    , "&intlarhk;" => "⨗"
    , "&pluscir;" => "⨢"
    , "&plusacir;" => "⨣"
    , "&simplus;" => "⨤"
    , "&plusdu;" => "⨥"
    , "&plussim;" => "⨦"
    , "&plustwo;" => "⨧"
    , "&mcomma;" => "⨩"
    , "&minusdu;" => "⨪"
    , "&loplus;" => "⨭"
    , "&roplus;" => "⨮"
    , "&Cross;" => "⨯"
    , "&timesd;" => "⨰"
    , "&timesbar;" => "⨱"
    , "&smashp;" => "⨳"
    , "&lotimes;" => "⨴"
    , "&rotimes;" => "⨵"
    , "&otimesas;" => "⨶"
    , "&Otimes;" => "⨷"
    , "&odiv;" => "⨸"
    , "&triplus;" => "⨹"
    , "&triminus;" => "⨺"
    , "&tritime;" => "⨻"
    , "&intprod;" => "⨼"
    , "&iprod;" => "⨼"
    , "&amalg;" => "⨿"
    , "&capdot;" => "⩀"
    , "&ncup;" => "⩂"
    , "&ncap;" => "⩃"
    , "&capand;" => "⩄"
    , "&cupor;" => "⩅"
    , "&cupcap;" => "⩆"
    , "&capcup;" => "⩇"
    , "&cupbrcap;" => "⩈"
    , "&capbrcup;" => "⩉"
    , "&cupcup;" => "⩊"
    , "&capcap;" => "⩋"
    , "&ccups;" => "⩌"
    , "&ccaps;" => "⩍"
    , "&ccupssm;" => "⩐"
    , "&And;" => "⩓"
    , "&Or;" => "⩔"
    , "&andand;" => "⩕"
    , "&oror;" => "⩖"
    , "&orslope;" => "⩗"
    , "&andslope;" => "⩘"
    , "&andv;" => "⩚"
    , "&orv;" => "⩛"
    , "&andd;" => "⩜"
    , "&ord;" => "⩝"
    , "&wedbar;" => "⩟"
    , "&sdote;" => "⩦"
    , "&simdot;" => "⩪"
    , "&congdot;" => "⩭"
    , "&easter;" => "⩮"
    , "&apacir;" => "⩯"
    , "&apE;" => "⩰"
    , "&eplus;" => "⩱"
    , "&pluse;" => "⩲"
    , "&Esim;" => "⩳"
    , "&Colone;" => "⩴"
    , "&Equal;" => "⩵"
    , "&ddotseq;" => "⩷"
    , "&eDDot;" => "⩷"
    , "&equivDD;" => "⩸"
    , "&ltcir;" => "⩹"
    , "&gtcir;" => "⩺"
    , "&ltquest;" => "⩻"
    , "&gtquest;" => "⩼"
    , "&leqslant;" => "⩽"
    , "&LessSlantEqual;" => "⩽"
    , "&les;" => "⩽"
    , "&geqslant;" => "⩾"
    , "&GreaterSlantEqual;" => "⩾"
    , "&ges;" => "⩾"
    , "&lesdot;" => "⩿"
    , "&gesdot;" => "⪀"
    , "&lesdoto;" => "⪁"
    , "&gesdoto;" => "⪂"
    , "&lesdotor;" => "⪃"
    , "&gesdotol;" => "⪄"
    , "&lessapprox;" => "⪅"
    , "&lap;" => "⪅"
    , "&gtrapprox;" => "⪆"
    , "&gap;" => "⪆"
    , "&lneq;" => "⪇"
    , "&lne;" => "⪇"
    , "&gneq;" => "⪈"
    , "&gne;" => "⪈"
    , "&lnapprox;" => "⪉"
    , "&lnap;" => "⪉"
    , "&gnapprox;" => "⪊"
    , "&gnap;" => "⪊"
    , "&lesseqqgtr;" => "⪋"
    , "&lEg;" => "⪋"
    , "&gtreqqless;" => "⪌"
    , "&gEl;" => "⪌"
    , "&lsime;" => "⪍"
    , "&gsime;" => "⪎"
    , "&lsimg;" => "⪏"
    , "&gsiml;" => "⪐"
    , "&lgE;" => "⪑"
    , "&glE;" => "⪒"
    , "&lesges;" => "⪓"
    , "&gesles;" => "⪔"
    , "&eqslantless;" => "⪕"
    , "&els;" => "⪕"
    , "&eqslantgtr;" => "⪖"
    , "&egs;" => "⪖"
    , "&elsdot;" => "⪗"
    , "&egsdot;" => "⪘"
    , "&el;" => "⪙"
    , "&eg;" => "⪚"
    , "&siml;" => "⪝"
    , "&simg;" => "⪞"
    , "&simlE;" => "⪟"
    , "&simgE;" => "⪠"
    , "&LessLess;" => "⪡"
    , "&GreaterGreater;" => "⪢"
    , "&glj;" => "⪤"
    , "&gla;" => "⪥"
    , "&ltcc;" => "⪦"
    , "&gtcc;" => "⪧"
    , "&lescc;" => "⪨"
    , "&gescc;" => "⪩"
    , "&smt;" => "⪪"
    , "&lat;" => "⪫"
    , "&smte;" => "⪬"
    , "&late;" => "⪭"
    , "&bumpE;" => "⪮"
    , "&PrecedesEqual;" => "⪯"
    , "&preceq;" => "⪯"
    , "&pre;" => "⪯"
    , "&SucceedsEqual;" => "⪰"
    , "&succeq;" => "⪰"
    , "&sce;" => "⪰"
    , "&prE;" => "⪳"
    , "&scE;" => "⪴"
    , "&precneqq;" => "⪵"
    , "&prnE;" => "⪵"
    , "&succneqq;" => "⪶"
    , "&scnE;" => "⪶"
    , "&precapprox;" => "⪷"
    , "&prap;" => "⪷"
    , "&succapprox;" => "⪸"
    , "&scap;" => "⪸"
    , "&precnapprox;" => "⪹"
    , "&prnap;" => "⪹"
    , "&succnapprox;" => "⪺"
    , "&scnap;" => "⪺"
    , "&Pr;" => "⪻"
    , "&Sc;" => "⪼"
    , "&subdot;" => "⪽"
    , "&supdot;" => "⪾"
    , "&subplus;" => "⪿"
    , "&supplus;" => "⫀"
    , "&submult;" => "⫁"
    , "&supmult;" => "⫂"
    , "&subedot;" => "⫃"
    , "&supedot;" => "⫄"
    , "&subseteqq;" => "⫅"
    , "&subE;" => "⫅"
    , "&supseteqq;" => "⫆"
    , "&supE;" => "⫆"
    , "&subsim;" => "⫇"
    , "&supsim;" => "⫈"
    , "&subsetneqq;" => "⫋"
    , "&subnE;" => "⫋"
    , "&supsetneqq;" => "⫌"
    , "&supnE;" => "⫌"
    , "&csub;" => "⫏"
    , "&csup;" => "⫐"
    , "&csube;" => "⫑"
    , "&csupe;" => "⫒"
    , "&subsup;" => "⫓"
    , "&supsub;" => "⫔"
    , "&subsub;" => "⫕"
    , "&supsup;" => "⫖"
    , "&suphsub;" => "⫗"
    , "&supdsub;" => "⫘"
    , "&forkv;" => "⫙"
    , "&topfork;" => "⫚"
    , "&mlcp;" => "⫛"
    , "&DoubleLeftTee;" => "⫤"
    , "&Dashv;" => "⫤"
    , "&Vdashl;" => "⫦"
    , "&Barv;" => "⫧"
    , "&vBar;" => "⫨"
    , "&vBarv;" => "⫩"
    , "&Vbar;" => "⫫"
    , "&Not;" => "⫬"
    , "&bNot;" => "⫭"
    , "&rnmid;" => "⫮"
    , "&cirmid;" => "⫯"
    , "&midcir;" => "⫰"
    , "&topcir;" => "⫱"
    , "&nhpar;" => "⫲"
    , "&parsim;" => "⫳"
    , "&parsl;" => "⫽"
    , "&fflig;" => "ﬀ"
    , "&filig;" => "ﬁ"
    , "&fllig;" => "ﬂ"
    , "&ffilig;" => "ﬃ"
    , "&ffllig;" => "ﬄ"
    , "&Ascr;" => "𝒜"
    , "&Cscr;" => "𝒞"
    , "&Dscr;" => "𝒟"
    , "&Gscr;" => "𝒢"
    , "&Jscr;" => "𝒥"
    , "&Kscr;" => "𝒦"
    , "&Nscr;" => "𝒩"
    , "&Oscr;" => "𝒪"
    , "&Pscr;" => "𝒫"
    , "&Qscr;" => "𝒬"
    , "&Sscr;" => "𝒮"
    , "&Tscr;" => "𝒯"
    , "&Uscr;" => "𝒰"
    , "&Vscr;" => "𝒱"
    , "&Wscr;" => "𝒲"
    , "&Xscr;" => "𝒳"
    , "&Yscr;" => "𝒴"
    , "&Zscr;" => "𝒵"
    , "&ascr;" => "𝒶"
    , "&bscr;" => "𝒷"
    , "&cscr;" => "𝒸"
    , "&dscr;" => "𝒹"
    , "&fscr;" => "𝒻"
    , "&hscr;" => "𝒽"
    , "&iscr;" => "𝒾"
    , "&jscr;" => "𝒿"
    , "&kscr;" => "𝓀"
    , "&lscr;" => "𝓁"
    , "&mscr;" => "𝓂"
    , "&nscr;" => "𝓃"
    , "&pscr;" => "𝓅"
    , "&qscr;" => "𝓆"
    , "&rscr;" => "𝓇"
    , "&sscr;" => "𝓈"
    , "&tscr;" => "𝓉"
    , "&uscr;" => "𝓊"
    , "&vscr;" => "𝓋"
    , "&wscr;" => "𝓌"
    , "&xscr;" => "𝓍"
    , "&yscr;" => "𝓎"
    , "&zscr;" => "𝓏"
    , "&Afr;" => "𝔄"
    , "&Bfr;" => "𝔅"
    , "&Dfr;" => "𝔇"
    , "&Efr;" => "𝔈"
    , "&Ffr;" => "𝔉"
    , "&Gfr;" => "𝔊"
    , "&Jfr;" => "𝔍"
    , "&Kfr;" => "𝔎"
    , "&Lfr;" => "𝔏"
    , "&Mfr;" => "𝔐"
    , "&Nfr;" => "𝔑"
    , "&Ofr;" => "𝔒"
    , "&Pfr;" => "𝔓"
    , "&Qfr;" => "𝔔"
    , "&Sfr;" => "𝔖"
    , "&Tfr;" => "𝔗"
    , "&Ufr;" => "𝔘"
    , "&Vfr;" => "𝔙"
    , "&Wfr;" => "𝔚"
    , "&Xfr;" => "𝔛"
    , "&Yfr;" => "𝔜"
    , "&afr;" => "𝔞"
    , "&bfr;" => "𝔟"
    , "&cfr;" => "𝔠"
    , "&dfr;" => "𝔡"
    , "&efr;" => "𝔢"
    , "&ffr;" => "𝔣"
    , "&gfr;" => "𝔤"
    , "&hfr;" => "𝔥"
    , "&ifr;" => "𝔦"
    , "&jfr;" => "𝔧"
    , "&kfr;" => "𝔨"
    , "&lfr;" => "𝔩"
    , "&mfr;" => "𝔪"
    , "&nfr;" => "𝔫"
    , "&ofr;" => "𝔬"
    , "&pfr;" => "𝔭"
    , "&qfr;" => "𝔮"
    , "&rfr;" => "𝔯"
    , "&sfr;" => "𝔰"
    , "&tfr;" => "𝔱"
    , "&ufr;" => "𝔲"
    , "&vfr;" => "𝔳"
    , "&wfr;" => "𝔴"
    , "&xfr;" => "𝔵"
    , "&yfr;" => "𝔶"
    , "&zfr;" => "𝔷"
    , "&Aopf;" => "𝔸"
    , "&Bopf;" => "𝔹"
    , "&Dopf;" => "𝔻"
    , "&Eopf;" => "𝔼"
    , "&Fopf;" => "𝔽"
    , "&Gopf;" => "𝔾"
    , "&Iopf;" => "𝕀"
    , "&Jopf;" => "𝕁"
    , "&Kopf;" => "𝕂"
    , "&Lopf;" => "𝕃"
    , "&Mopf;" => "𝕄"
    , "&Oopf;" => "𝕆"
    , "&Sopf;" => "𝕊"
    , "&Topf;" => "𝕋"
    , "&Uopf;" => "𝕌"
    , "&Vopf;" => "𝕍"
    , "&Wopf;" => "𝕎"
    , "&Xopf;" => "𝕏"
    , "&Yopf;" => "𝕐"
    , "&aopf;" => "𝕒"
    , "&bopf;" => "𝕓"
    , "&copf;" => "𝕔"
    , "&dopf;" => "𝕕"
    , "&eopf;" => "𝕖"
    , "&fopf;" => "𝕗"
    , "&gopf;" => "𝕘"
    , "&hopf;" => "𝕙"
    , "&iopf;" => "𝕚"
    , "&jopf;" => "𝕛"
    , "&kopf;" => "𝕜"
    , "&lopf;" => "𝕝"
    , "&mopf;" => "𝕞"
    , "&nopf;" => "𝕟"
    , "&oopf;" => "𝕠"
    , "&popf;" => "𝕡"
    , "&qopf;" => "𝕢"
    , "&ropf;" => "𝕣"
    , "&sopf;" => "𝕤"
    , "&topf;" => "𝕥"
    , "&uopf;" => "𝕦"
    , "&vopf;" => "𝕧"
    , "&wopf;" => "𝕨"
    , "&xopf;" => "𝕩"
    , "&yopf;" => "𝕪"
    , "&zopf;" => "𝕫"
    ]
